[% 
    title = 'Releases: ' _ [% release.data.title %];
    htmltitle = title ;

    crumb4_name = 'Home' ;
    crumb4_href = '/' ;
    crumb3_name = 'Releases' ;
    crumb3_href = '/release-list' ;
    crumb2_name = [% release.data.title %] ;
    crumb2_href = '/release-item/' _ [% release.data.articleid %];
    crumb1_name = 'Lyrics' ;
%]

<table class="lyric">
<tr>
	<th><a href="/release-item?name=[% release.data.quickname %]">[% release.data.title %]</a></th>
	<th align="right">[% release.data.snippet %]</th>
</tr>
<tr><td>
	<p>Tracks:</p>
	<ul>[% FOREACH song = release.lyrics %]<li><a href="#[% song.data.data.quickname %]">[% song.title %]</a></li>[% END %]</ul>
	</td>
	<td><img src="[% webpath %]/[% release.data.link %]" alt="[% item.data.tag %]" width="200" align="right" /></td>
</tr>
</table>

[% FOREACH song = lyrics %]
[% lyric = song.data %]
<a name="[% lyric.data.quickname %]">&nbsp;</a>
	[% INCLUDE "lyrics/lyric-block.html" %]
[% END %]
